@@ -5,32 +5,31 @@ package org.gcube.portlets.user.td.gwtservice.client.rpc;
 
 import java.util.ArrayList;
 
+import org.gcube.portlets.user.td.gwtservice.shared.codelisthelper.CodelistMappingSession;
 import org.gcube.portlets.user.td.gwtservice.shared.csv.AvailableCharsetList;
-import org.gcube.portlets.user.td.gwtservice.shared.csv.CSVExportMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.csv.CSVExportSession;
-import org.gcube.portlets.user.td.gwtservice.shared.csv.CSVImportMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.csv.CSVImportSession;
-import org.gcube.portlets.user.td.gwtservice.shared.csv.CSVRowError;
+import org.gcube.portlets.user.td.gwtservice.shared.csv.CheckCSVSession;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTServiceException;
-import org.gcube.portlets.user.td.gwtservice.shared.extract.ExtractCodelistMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.extract.ExtractCodelistSession;
 import org.gcube.portlets.user.td.gwtservice.shared.file.FileUploadMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.file.HeaderPresence;
 import org.gcube.portlets.user.td.gwtservice.shared.history.OpHistory;
 import org.gcube.portlets.user.td.gwtservice.shared.history.RollBackSession;
-import org.gcube.portlets.user.td.gwtservice.shared.history.RollBackSessionMonitor;
-import org.gcube.portlets.user.td.gwtservice.shared.sdmx.SDMXExportMonitor;
+import org.gcube.portlets.user.td.gwtservice.shared.json.JSONExportSession;
+import org.gcube.portlets.user.td.gwtservice.shared.licenses.LicenceData;
+import org.gcube.portlets.user.td.gwtservice.shared.map.MapCreationSession;
+import org.gcube.portlets.user.td.gwtservice.shared.monitor.BackgroundOperationMonitorSession;
+import org.gcube.portlets.user.td.gwtservice.shared.monitor.OperationMonitor;
+import org.gcube.portlets.user.td.gwtservice.shared.monitor.OperationMonitorSession;
 import org.gcube.portlets.user.td.gwtservice.shared.sdmx.SDMXExportSession;
-import org.gcube.portlets.user.td.gwtservice.shared.sdmx.SDMXImportMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.sdmx.SDMXImportSession;
-import org.gcube.portlets.user.td.gwtservice.shared.share.ShareInfo;
+import org.gcube.portlets.user.td.gwtservice.shared.share.ShareTabResource;
+import org.gcube.portlets.user.td.gwtservice.shared.share.ShareTemplate;
 import org.gcube.portlets.user.td.gwtservice.shared.source.SDMXRegistrySource;
-import org.gcube.portlets.user.td.gwtservice.shared.task.TaskResubmitMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.task.TaskResubmitSession;
-import org.gcube.portlets.user.td.gwtservice.shared.task.TaskResumeMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.task.TaskResumeSession;
 import org.gcube.portlets.user.td.gwtservice.shared.task.ValidationsTasksMetadata;
-import org.gcube.portlets.user.td.gwtservice.shared.template.TemplateApplyMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.template.TemplateApplySession;
 import org.gcube.portlets.user.td.gwtservice.shared.template.TemplateData;
 import org.gcube.portlets.user.td.gwtservice.shared.template.TemplateDeleteSession;
@@ -40,34 +39,33 @@ import org.gcube.portlets.user.td.gwtservice.shared.tr.TabResource;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.TableData;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.batch.Occurrences;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.batch.OccurrencesForReplaceBatchColumnSession;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.batch.ReplaceBatchColumnMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.batch.ReplaceBatchColumnSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.clone.CloneTabularResourceSession;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.column.DeleteColumnMonitor;
+import org.gcube.portlets.user.td.gwtservice.shared.tr.column.AddColumnSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.column.DeleteColumnSession;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.column.LabelColumnMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.column.LabelColumnSession;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.column.ReplaceColumnMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.column.ReplaceColumnSession;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.column.type.ChangeColumnTypeMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.column.type.ChangeColumnTypeSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.metadata.TRMetadata;
+import org.gcube.portlets.user.td.gwtservice.shared.tr.normalization.DenormalizationSession;
+import org.gcube.portlets.user.td.gwtservice.shared.tr.normalization.NormalizationSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.open.TDOpenSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.paging.CodelistPagingLoadConfig;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.paging.CodelistPagingLoadResult;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.rows.DeleteRowsMonitor;
+import org.gcube.portlets.user.td.gwtservice.shared.tr.resources.ResourceTDDescriptor;
+import org.gcube.portlets.user.td.gwtservice.shared.tr.resources.ResourceTDType;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.rows.DeleteRowsSession;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.rows.DuplicatesMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.rows.DuplicatesSession;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.rows.EditRowMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.rows.EditRowSession;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.table.ChangeTableTypeMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.table.ChangeTableTypeSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.table.metadata.TabMetadata;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.table.metadata.TabValidationsMetadata;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.type.Agencies;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.type.Codelist;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.type.Dataset;
+import org.gcube.portlets.user.td.gwtservice.shared.tr.union.UnionSession;
+import org.gcube.portlets.user.td.gwtservice.shared.uriresolver.UriResolverSession;
+import org.gcube.portlets.user.td.gwtservice.shared.user.UserInfo;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 
 import com.google.gwt.user.client.rpc.RemoteService;
@@ -99,7 +97,25 @@ public interface TDGWTService extends RemoteService {
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public String hello() throws TDGWTServiceException;
+	public UserInfo hello() throws TDGWTServiceException;
+
+	/**
+	 * Restore UI session
+	 * 
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public TRId restoreUISession() throws TDGWTServiceException;
+
+	/**
+	 * Resolve Uri
+	 * 
+	 * @param uriResolverSession
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public String getUriFromResolver(UriResolverSession uriResolverSession)
+			throws TDGWTServiceException;
 
 	// TabularResource
 	/**
@@ -111,7 +127,17 @@ public interface TDGWTService extends RemoteService {
 	public TRId getCurrentTRId() throws TDGWTServiceException;
 
 	/**
-	 * Get informations on the current tabular resource
+	 * Get information on the current tabular resource don't call service
+	 * 
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public TabResource getInSessionTabResourceInfo()
+			throws TDGWTServiceException;
+
+	/**
+	 * Get informations on the current tabular resource call service
+	 * 
 	 * 
 	 * @return
 	 * @throws TDGWTServiceException
@@ -221,41 +247,62 @@ public interface TDGWTService extends RemoteService {
 	public ColumnData getConnection(RefColumn refColumn)
 			throws TDGWTServiceException;
 
-	// Task
 	/**
-	 * Get Operation Monitor during the resubmit task
+	 * Close All Tabular Resources
+	 * 
 	 * 
-	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public TaskResubmitMonitor getTaskResubmitMonitor()
+	public void closeAllTabularResources() throws TDGWTServiceException;
+
+	/**
+	 * Close Tabular Resource with TRId equals to closeTRId and open if not null
+	 * that with TRId equals to openTRId
+	 * 
+	 * @param openTRId
+	 * @throws TDGWTServiceException
+	 */
+	public void closeTabularResourceAndOpen(TRId openTRId, TRId closeTRId)
 			throws TDGWTServiceException;
 
+	/**
+	 * Close Tabular Resource with TRId equals to closeTRId
+	 * 
+	 * @param closeTRId
+	 * @throws TDGWTServiceException
+	 */
+	public void closeTabularResource(TRId closeTRId)
+			throws TDGWTServiceException;
+
+	/**
+	 * Set Current Tabular Resource that passed as parameter if not null
+	 * 
+	 * 
+	 * @param activeTRId
+	 * @throws TDGWTServiceException
+	 */
+	public void setActiveTabularResource(TRId activeTRId)
+			throws TDGWTServiceException;
+
+	// Task
 	/**
 	 * Resubmit task
 	 * 
 	 * @param taskResubmitSession
-	 * @throws TDGWTServiceException
-	 */
-	public void startTaskResubmit(TaskResubmitSession taskResubmitSession)
-			throws TDGWTServiceException;
-
-	/**
-	 * Get Operation Monitor during the resume task
-	 * 
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public TaskResumeMonitor getTaskResumeMonitor()
+	public String startTaskResubmit(TaskResubmitSession taskResubmitSession)
 			throws TDGWTServiceException;
 
 	/**
 	 * Resume task
 	 * 
 	 * @param taskResumeSession
+	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public void startTaskResume(TaskResumeSession taskResumeSession)
+	public String startTaskResume(TaskResumeSession taskResumeSession)
 			throws TDGWTServiceException;
 
 	// Validations
@@ -298,44 +345,38 @@ public interface TDGWTService extends RemoteService {
 	 * @param rollBackSession
 	 * @throws TDGWTServiceException
 	 */
-	public void rollBack(RollBackSession rollBackSession)
-			throws TDGWTServiceException;
-
-	/**
-	 * Get Operation Monitor during the rollback
-	 * 
-	 * @return
-	 * @throws TDGWTServiceException
-	 */
-	public RollBackSessionMonitor getRollBackMonitor()
+	public String startRollBack(RollBackSession rollBackSession)
 			throws TDGWTServiceException;
 
 	/**
 	 * Call discard operation on tabular resource
 	 * 
 	 * @param trId
-	 * @throws TDGWTServiceException
-	 */
-	public RollBackSession discard(TRId trId) throws TDGWTServiceException;
-
-	// Share
-	/**
-	 * Retrieves information sharing on the tabular resource
-	 * 
-	 * @param trId
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public ShareInfo getShareInfo(TRId trId) throws TDGWTServiceException;
+	public String startDiscard(TRId trId) throws TDGWTServiceException;
 
+	// Share
 	/**
-	 * Share sabular resource
+	 * Share tabular resource
 	 * 
 	 * @param shareInfo
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public void setShare(ShareInfo shareInfo) throws TDGWTServiceException;
+	public void setShare(ShareTabResource shareInfo)
+			throws TDGWTServiceException;
+
+	/**
+	 * Share template
+	 * 
+	 * @param shareTemplate
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public void setShareTemplate(ShareTemplate shareTemplate)
+			throws TDGWTServiceException;
 
 	// Open
 
@@ -361,10 +402,11 @@ public interface TDGWTService extends RemoteService {
 	/**
 	 * Start clone tabular resource
 	 * 
-	 * @param labelColumnSession
+	 * @param cloneTabularResourceSession
+	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public TRId startCloneTabularResource(
+	public String startCloneTabularResource(
 			CloneTabularResourceSession cloneTabularResourceSession)
 			throws TDGWTServiceException;
 
@@ -393,7 +435,7 @@ public interface TDGWTService extends RemoteService {
 	 * @param s
 	 * @throws TDGWTServiceException
 	 */
-	public void startTDOpen(TDOpenSession tdOpenSession)
+	public void tdOpen(TDOpenSession tdOpenSession)
 			throws TDGWTServiceException;
 
 	/**
@@ -488,31 +530,14 @@ public interface TDGWTService extends RemoteService {
 	/**
 	 * Start SDMX Import and invokes the client library
 	 * 
-	 * @param s
-	 * @throws TDGWTServiceException
-	 */
-	public void startSDMXImport(SDMXImportSession sdmxImportSession)
-			throws TDGWTServiceException;
-
-	/**
-	 * Get Operation Monitor during the SDMX Import operation
-	 * 
+	 * @param sdmxImportSession
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public SDMXImportMonitor getSDMXImportMonitor()
-			throws TDGWTServiceException;
-
-	// Import CSV
-	/**
-	 * Get File Upload Monitor during the file upload operation in Import CSV
-	 * 
-	 * @return
-	 * @throws TDGWTServiceException
-	 */
-	public FileUploadMonitor getFileUploadMonitor()
+	public String startSDMXImport(SDMXImportSession sdmxImportSession)
 			throws TDGWTServiceException;
 
+	// CSV Import
 	/**
 	 * 
 	 * @param s
@@ -556,7 +581,7 @@ public interface TDGWTService extends RemoteService {
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public ArrayList<CSVRowError> checkCSV(long errorsLimit)
+	public CheckCSVSession checkCSV(long errorsLimit)
 			throws TDGWTServiceException;
 
 	/**
@@ -565,192 +590,170 @@ public interface TDGWTService extends RemoteService {
 	 * @param s
 	 * @throws TDGWTServiceException
 	 */
-	public void startCSVImport(CSVImportSession csvImportSession)
+	public String startCSVImport(CSVImportSession csvImportSession)
 			throws TDGWTServiceException;
 
-	/**
-	 * Get Operation Monitor during the CSV Import operation
-	 * 
-	 * @return
-	 * @throws TDGWTServiceException
-	 */
-	public CSVImportMonitor getCSVImportMonitor() throws TDGWTServiceException;
-
 	// Export CSV
-	/**
-	 * Get Operation Monitor during the CSV Export operation
-	 * 
-	 * @return
-	 * @throws TDGWTServiceException
-	 */
-	public CSVExportMonitor getCSVExportMonitor() throws TDGWTServiceException;
-
 	/**
 	 * Start CSV Export and invokes the client library
 	 * 
 	 * @param csvExportSession
+	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public void startCSVExport(CSVExportSession csvExportSession)
+	public String startCSVExport(CSVExportSession csvExportSession)
 			throws TDGWTServiceException;
 
 	// Export SDMX
 	/**
-	 * Get Operation Monitor during the SDMX Export operation
+	 * Start SDMX Export and invokes the client library
 	 * 
+	 * @param exportSession
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public SDMXExportMonitor getSDMXExportMonitor()
+	public String startSDMXExport(SDMXExportSession exportSession)
 			throws TDGWTServiceException;
 
+	// Export JSON
 	/**
-	 * Start SDMX Export and invokes the client library
+	 * Start JSON Export and invokes the client library
 	 * 
-	 * @param sdmxExportSession
+	 * @param jsonExportSession
+	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public void startSDMXExport(SDMXExportSession exportSession)
+	public String startJSONExport(JSONExportSession jsonExportSession)
 			throws TDGWTServiceException;
 
 	// Table Operations
-	/**
-	 * Get Operation Monitor during the Change Table Type operation
-	 * 
-	 * 
-	 * @return
-	 * @throws TDGWTServiceException
-	 */
-	public ChangeTableTypeMonitor getChangeTableTypeMonitor()
-			throws TDGWTServiceException;
 
 	/**
 	 * Start change table type
 	 * 
-	 * @param labelColumnSession
+	 * @param changeTableTypeSession
+	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public void startChangeTableType(
+	public String startChangeTableType(
 			ChangeTableTypeSession changeTableTypeSession)
 			throws TDGWTServiceException;
 
+	/**
+	 * Start Union and invokes the client library
+	 * 
+	 * @param unionSession
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public String startUnion(UnionSession unionSession)
+			throws TDGWTServiceException;
+
 	// Rows Operations
-	/**
-	 * Get Operation Monitor during the Edit Row operation
-	 * 
-	 * 
-	 * @return
-	 * @throws TDGWTServiceException
-	 */
-	public EditRowMonitor getEditRowMonitor() throws TDGWTServiceException;
-
 	/**
 	 * Start edit row or add row
 	 * 
-	 * @param labelColumnSession
-	 * @throws TDGWTServiceException
-	 */
-	public void startEditRow(EditRowSession editRowSession)
-			throws TDGWTServiceException;
-
-	/**
-	 * Get Operation Monitor during the Delete Rows operation
-	 * 
-	 * 
+	 * @param editRowSession
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public DeleteRowsMonitor getDeleteRowsMonitor()
+	public String startEditRow(EditRowSession editRowSession)
 			throws TDGWTServiceException;
 
 	/**
 	 * Start delete rows
 	 * 
-	 * @param labelColumnSession
-	 * @throws TDGWTServiceException
-	 */
-	public void startDeleteRows(DeleteRowsSession deleteRowsSession)
-			throws TDGWTServiceException;
-
-	/**
-	 * Get Operation Monitor during the operation on duplicates
-	 * 
-	 * 
+	 * @param deleteRowsSession
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public DuplicatesMonitor getDuplicatesMonitor()
+	public String startDeleteRows(DeleteRowsSession deleteRowsSession)
 			throws TDGWTServiceException;
 
 	/**
 	 * Start operation on duplicates
 	 * 
-	 * @param labelColumnSession
+	 * @param duplicatesSession
+	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public void startDuplicates(DuplicatesSession duplicatesSession)
+	public String startDuplicates(DuplicatesSession duplicatesSession)
 			throws TDGWTServiceException;
 
 	// Column Operation
 
 	/**
-	 * Get Operation Monitor during the Change Column Type operation
+	 * Start change column type
 	 * 
+	 * 
+	 * @param changeColumnTypeSession
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public ChangeColumnTypeMonitor getChangeColumnTypeMonitor()
-			throws TDGWTServiceException;
-
-	/**
-	 * Start change column type
-	 * 
-	 * @param changeColumnTypeSession
-	 * @throws TDGWTServiceException
-	 */
-	public void startChangeColumnType(
+	public String startChangeColumnType(
 			ChangeColumnTypeSession changeColumnTypeSession)
 			throws TDGWTServiceException;
 
 	/**
-	 * Get Operation Monitor during the Delete Column operation
-	 * 
+	 * Start add column
 	 * 
+	 * @param addColumnSession
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public DeleteColumnMonitor getDeleteColumnMonitor()
+	public String startAddColumn(AddColumnSession addColumnSession)
 			throws TDGWTServiceException;
 
 	/**
 	 * Start delete column
 	 * 
-	 * 
 	 * @param deleteColumnSession
-	 * @throws TDGWTServiceException
-	 */
-	public void startDeleteColumn(DeleteColumnSession deleteColumnSession)
-			throws TDGWTServiceException;
-
-	/**
-	 * Get Operation Monitor during the Change the Column Label operation
-	 * 
-	 * 
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public LabelColumnMonitor getLabelColumnMonitor()
+	public String startDeleteColumn(DeleteColumnSession deleteColumnSession)
 			throws TDGWTServiceException;
 
 	/**
 	 * Start change the column label
 	 * 
 	 * @param labelColumnSession
+	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public void startLabelColumn(LabelColumnSession labelColumnSession)
+	public String startLabelColumn(LabelColumnSession labelColumnSession)
 			throws TDGWTServiceException;
 
+	/**
+	 * Start split column
+	 * 
+	 * @param splitColumnSession
+	 * @throws TDGWTServiceException
+	 * 
+	 *             public void startSplitColumn(SplitColumnSession
+	 *             splitColumnSession) throws TDGWTServiceException;
+	 */
+
+	/**
+	 * Start merge column
+	 * 
+	 * @param splitColumnSession
+	 * @throws TDGWTServiceException
+	 * 
+	 *             public void startMergeColumn(MergeColumnSession
+	 *             mergeColumnSession) throws TDGWTServiceException;
+	 */
+
+	/**
+	 * Start group by
+	 * 
+	 * @param groupBySession
+	 * @throws TDGWTServiceException
+	 * 
+	 *             public void startGroupBy(GroupBySession groupBySession)
+	 *             throws TDGWTServiceException;
+	 */
+
 	// BatchReplace Operations
 	/**
 	 * Retrieves the values ​​in a column grouped by number of occurrences
@@ -764,44 +767,26 @@ public interface TDGWTService extends RemoteService {
 			OccurrencesForReplaceBatchColumnSession occurrencesForReplaceBatchColumnSession)
 			throws TDGWTServiceException;
 
-	/**
-	 * Get Operation Monitor during the batch replace on column
-	 * 
-	 * 
-	 * @return
-	 * @throws TDGWTServiceException
-	 */
-	public ReplaceBatchColumnMonitor getReplaceBatchColumnMonitor()
-			throws TDGWTServiceException;
-
 	/**
 	 * Start batch replace on column
 	 * 
 	 * @param replaceBatchColumnSession
+	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public void startReplaceBatchColumn(
+	public String startReplaceBatchColumn(
 			ReplaceBatchColumnSession replaceBatchColumnSession)
 			throws TDGWTServiceException;
 
 	// Replace Operation
 	/**
-	 * Get Operation Monitor during the replace the Column Value operation
-	 * 
+	 * Start replace the column value
 	 * 
+	 * @param replaceColumnSession
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public ReplaceColumnMonitor getReplaceColumnMonitor()
-			throws TDGWTServiceException;
-
-	/**
-	 * Start replace the column value
-	 * 
-	 * @param labelColumnSession
-	 * @throws TDGWTServiceException
-	 */
-	public void startReplaceColumn(ReplaceColumnSession replaceColumnSession)
+	public String startReplaceColumn(ReplaceColumnSession replaceColumnSession)
 			throws TDGWTServiceException;
 
 	// Templates
@@ -814,22 +799,14 @@ public interface TDGWTService extends RemoteService {
 	 */
 	public ArrayList<TemplateData> getTemplates() throws TDGWTServiceException;
 
-	/**
-	 * Get Operation Monitor during Apply Template operation
-	 * 
-	 * @return
-	 * @throws TDGWTServiceException
-	 */
-	public TemplateApplyMonitor getTemplateApplyMonitor()
-			throws TDGWTServiceException;
-
 	/**
 	 * Start Apply Template
 	 * 
 	 * @param templateApplySession
+	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	void startTemplateApply(TemplateApplySession templateApplySession)
+	public String startTemplateApply(TemplateApplySession templateApplySession)
 			throws TDGWTServiceException;
 
 	/**
@@ -838,7 +815,7 @@ public interface TDGWTService extends RemoteService {
 	 * @param templateDeleteSession
 	 * @throws TDGWTServiceException
 	 */
-	void startTemplateDelete(TemplateDeleteSession templateDeleteSession)
+	public void templateDelete(TemplateDeleteSession templateDeleteSession)
 			throws TDGWTServiceException;
 
 	// Locales
@@ -848,7 +825,16 @@ public interface TDGWTService extends RemoteService {
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	ArrayList<String> getLocales() throws TDGWTServiceException;
+	public ArrayList<String> getLocales() throws TDGWTServiceException;
+
+	// Licences
+	/**
+	 * Retrieve licences supported
+	 * 
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public ArrayList<LicenceData> getLicences() throws TDGWTServiceException;
 
 	// History
 	/**
@@ -857,7 +843,7 @@ public interface TDGWTService extends RemoteService {
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	ArrayList<OpHistory> getHistory() throws TDGWTServiceException;
+	public ArrayList<OpHistory> getHistory() throws TDGWTServiceException;
 
 	/**
 	 * Retrieve History for specific tabular resource
@@ -866,14 +852,15 @@ public interface TDGWTService extends RemoteService {
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	ArrayList<OpHistory> getHistory(TRId trId) throws TDGWTServiceException;
+	public ArrayList<OpHistory> getHistory(TRId trId)
+			throws TDGWTServiceException;
 
 	/**
 	 * 
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	OpHistory getLastOperationInfo() throws TDGWTServiceException;
+	public OpHistory getLastOperationInfo() throws TDGWTServiceException;
 
 	/**
 	 * 
@@ -881,24 +868,139 @@ public interface TDGWTService extends RemoteService {
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	OpHistory getLastOperationInfo(TRId trId) throws TDGWTServiceException;
+	public OpHistory getLastOperationInfo(TRId trId)
+			throws TDGWTServiceException;
 
-	// Extract Codelist
+	// Helper Extract Codelist
 	/**
-	 * Get Operation Monitor during the Extract Codelist operation
+	 * Start Extract Codelist and invokes the client library
+	 * 
+	 * 
+	 * @param extractCodelistSession
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public String startExtractCodelist(
+			ExtractCodelistSession extractCodelistSession)
+			throws TDGWTServiceException;
+
+	// Helper Codelist Mapping Import
+	/**
+	 * 
+	 * @param codelistMappingSession
+	 * @throws TDGWTServiceException
+	 */
+	public void setCodelistMappingSession(
+			CodelistMappingSession codelistMappingSession)
+			throws TDGWTServiceException;
+
+	/**
+	 * 
+	 * @param codelistMappingSession
+	 * @throws TDGWTServiceException
+	 */
+	public void getFileFromWorkspace(
+			CodelistMappingSession codelistMappingSession)
+			throws TDGWTServiceException;
+
+	/**
+	 * Start Codelist Mapping Import
+	 * 
+	 * @param codelistMappingSession
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public String startCodelistMappingImport(
+			CodelistMappingSession codelistMappingSession)
+			throws TDGWTServiceException;
+
+	// Normalization
+	/**
+	 * Start Normalization and invokes the client library
+	 * 
+	 * @param normalizationSession
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public String startNormalization(NormalizationSession normalizationSession)
+			throws TDGWTServiceException;
+
+	// Denormalization
+	/**
+	 * Start Denormalization and invokes the client library
+	 * 
+	 * 
+	 * @param denormalizationSession
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public String startDenormalization(
+			DenormalizationSession denormalizationSession)
+			throws TDGWTServiceException;
+
+	// Operation Monitor
+	/**
+	 * Get Operation Monitor
 	 * 
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public ExtractCodelistMonitor getExtractCodelistMonitor() throws TDGWTServiceException;
+	public OperationMonitor getOperationMonitor(
+			OperationMonitorSession operationMonitorSession)
+			throws TDGWTServiceException;
 
 	/**
-	 * Start Extract Codelist and invokes the client library
-	 *
-	 * @param extractCodelistSession
+	 * Get List of Background Operation Monitor
+	 * 
+	 * @param backgroundOperationMonitorSession
+	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public void startExtractCodelist(ExtractCodelistSession extractCodelistSession)
+	public ArrayList<OperationMonitor> getBackgroundOperationMonitor(
+			BackgroundOperationMonitorSession backgroundOperationMonitorSession)
+			throws TDGWTServiceException;
+
+	// File Upload Monitor
+	/**
+	 * Get File Upload Monitor during the file upload operation in Import CSV
+	 * 
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public FileUploadMonitor getFileUploadMonitor()
+			throws TDGWTServiceException;
+
+	// Resources TD
+	/**
+	 * Retrieves the resources of a specific tabular resource
+	 * 
+	 * @param trId
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public ArrayList<ResourceTDDescriptor> getResourcesTD(TRId trId)
+			throws TDGWTServiceException;
+
+	/**
+	 * Retrieves the resources of a specific tabular resource by type
+	 * 
+	 * @param trId
+	 * @param resourceTDType
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public ArrayList<ResourceTDDescriptor> getResourcesTDByType(TRId trId,
+			ResourceTDType resourceTDType) throws TDGWTServiceException;
+
+	// GIS MAP
+	/**
+	 * Start Map Creation and invokes the client library
+	 * 
+	 * @param mapCreationSession
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public String startMapCreation(MapCreationSession mapCreationSession)
 			throws TDGWTServiceException;
 
 }
